<?php

namespace Testprovider\Testpackage\Providers;

use Illuminate\Support\ServiceProvider;

class TestpackageServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'testpackage');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'testpackage');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('testprovider.testpackage', function ($app) {
            return $this->app->make('Testprovider\Testpackage\Testpackage');
        });

        // Bind Post to repository
        $this->app->bind(
            'Testprovider\Testpackage\Interfaces\PostRepositoryInterface',
            \Testprovider\Testpackage\Repositories\Eloquent\PostRepository::class
        );
        // Bind Category to repository
        $this->app->bind(
            'Testprovider\Testpackage\Interfaces\CategoryRepositoryInterface',
            \Testprovider\Testpackage\Repositories\Eloquent\CategoryRepository::class
        );

        $this->app->register(\Testprovider\Testpackage\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Testprovider\Testpackage\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['testprovider.testpackage'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('testprovider/testpackage.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/testpackage')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/testpackage')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
